==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebPaneDragStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragStartEventArgsDetailDescriptionMetadata } from "./WebPaneDragStartEventArgsDetailDescriptionMetadata";
import { WebPaneDragStartEventArgsDescription } from "./WebPaneDragStartEventArgsDescription";
/**
 * @hidden
 */
var WebPaneDragStartEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragStartEventArgsDescriptionMetadata, _super);
    function WebPaneDragStartEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragStartEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneDragStartEventArgsDescriptionMetadata.a == null) {
            WebPaneDragStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragStartEventArgsDescriptionMetadata.c(WebPaneDragStartEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPaneDragStartEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebPaneDragStartEventArgsDescriptionMetadata.a);
        WebPaneDragStartEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPaneDragStartEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragStartEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPaneDragStartEventArgsDetail");
    };
    WebPaneDragStartEventArgsDescriptionMetadata.d = function (a) {
        WebPaneDragStartEventArgsDescriptionMetadata.b(a);
        a.ad("WebPaneDragStartEventArgs", function () { return new WebPaneDragStartEventArgsDescription(); });
        a.ac("WebPaneDragStartEventArgs", WebPaneDragStartEventArgsDescriptionMetadata.a);
    };
    WebPaneDragStartEventArgsDescriptionMetadata.$t = markType(WebPaneDragStartEventArgsDescriptionMetadata, 'WebPaneDragStartEventArgsDescriptionMetadata');
    WebPaneDragStartEventArgsDescriptionMetadata.a = null;
    return WebPaneDragStartEventArgsDescriptionMetadata;
}(Base));
export { WebPaneDragStartEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebPaneDragStartEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragStartEventArgsDetailDescriptionMetadata } from "./WebPaneDragStartEventArgsDetailDescriptionMetadata";
import { WebPaneDragStartEventArgsDescription } from "./WebPaneDragStartEventArgsDescription";
/**
 * @hidden
 */
var WebPaneDragStartEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneDragStartEventArgsDescriptionMetadata, _super);
    function WebPaneDragStartEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneDragStartEventArgsDescriptionMetadata.b = function (a) {
        if (WebPaneDragStartEventArgsDescriptionMetadata.a == null) {
            WebPaneDragStartEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneDragStartEventArgsDescriptionMetadata.c(WebPaneDragStartEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPaneDragStartEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebPaneDragStartEventArgsDescriptionMetadata.a);
        WebPaneDragStartEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPaneDragStartEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneDragStartEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPaneDragStartEventArgsDetail");
    };
    WebPaneDragStartEventArgsDescriptionMetadata.d = function (a) {
        WebPaneDragStartEventArgsDescriptionMetadata.b(a);
        a.ae("WebPaneDragStartEventArgs", function () { return new WebPaneDragStartEventArgsDescription(); });
        a.ad("WebPaneDragStartEventArgs", WebPaneDragStartEventArgsDescriptionMetadata.a);
    };
    WebPaneDragStartEventArgsDescriptionMetadata.$t = markType(WebPaneDragStartEventArgsDescriptionMetadata, 'WebPaneDragStartEventArgsDescriptionMetadata');
    WebPaneDragStartEventArgsDescriptionMetadata.a = null;
    return WebPaneDragStartEventArgsDescriptionMetadata;
}(Base));
export { WebPaneDragStartEventArgsDescriptionMetadata };
